@@ -1,6 +1,6 @@
 /*
  * OfficeFloor - http://www.officefloor.net
- * Copyright (C) 2005-2012 Daniel Sagenschneider
+ * Copyright (C) 2005-2013 Daniel Sagenschneider
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,7 +15,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
 package net.officefloor.tutorial.dynamichttpserver;
 
 import junit.framework.TestCase;
@@ -50,7 +49,7 @@ public class DynamicHttpServerTest extends TestCase {
 
 		// Send request for dynamic page
 		HttpResponse response = new DefaultHttpClient().execute(new HttpGet(
-				"http://localhost:7878/example"));
+				"http://localhost:7878/example.woof"));
 
 		// Ensure request is successful
 		assertEquals("Request should be successful", 200, response
